@@ -25,8 +25,8 @@ Usage::
     describe_source_servers_paginator: DescribeSourceServersPaginator = client.get_paginator("describe_source_servers")
     ```
 """
-from mypy_boto3_mgn.client import mgnClient
-from mypy_boto3_mgn.paginator import (
+from .client import mgnClient
+from .paginator import (
     DescribeJobLogItemsPaginator,
     DescribeJobsPaginator,
     DescribeReplicationConfigurationTemplatesPaginator,
